@@ -113,7 +113,7 @@ void CameraUI::InitLangStrings(){
     langStrings["Greek"] = "el";
 
     langStrings["Finnish"] = "fi";
-    langStrings["French"] = "fe";
+    langStrings["French"] = "fr";
     langStrings["Hebrew"] = "iw";
     langStrings["Hungarian"] = "hu";
     langStrings["Indonesian"] = "id";
